@@ -3,7 +3,7 @@ BEGIN {
   $SyForm::AUTHORITY = 'cpan:GETTY';
 }
 # ABSTRACT: SyForm - a role driven form management
-$SyForm::VERSION = '0.004';
+$SyForm::VERSION = '0.005';
 use Moose::Role;
 use Tie::IxHash;
 use Carp qw( croak );
@@ -286,7 +286,7 @@ SyForm - SyForm - a role driven form management
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -302,6 +302,9 @@ version 0.004
       isa => 'Int',
       label => 'Your age',
     },
+    'unchecked' => {
+      label => 'Unchecked',
+    },
   ]);
 
   $form->does('SyForm'); # its all roles
@@ -309,16 +312,57 @@ version 0.004
   $form->field('username')->does('SyForm::Field::Label');
   $form->field('username')->does('SyForm::Field::Verify');
 
+  # Roles are only automatically loaded on requirement
+  !$form->field('unchecked')->does('SyForm::Field::Verify');
+
   my $view = $form->process( username => 'YoCoolCopKiller', age => 13 );
 
-  if ($view->success) {
-    my $vars = $view->field('username')->result;  
+  # or ...
+  # $values = $form->process_values(%args);
+  # my $value = $values->value;
+  # !$values->can('success'); # values are only the input
+  # $results = $form->process_results(%args);
+  # my $result = $results->username;
+  # my $value = $results->values->username; # same as above $value
+  # my $success = $result->success # result is after check
+
+  for (@{$view->field_names}) {
+    my $input_value = $view->field($_)->value;
+    if ($view->success) {
+      my $verified_result = $view->field($_)->result;  
+    } else {
+      my $verified_result_if_exist = $view->field($_)->result;
+    }
+    # for access to the main B<SyForm::Field> of the view field
+    my $syform_field = $view->field($_)->field;
   }
 
 =head1 DESCRIPTION
 
 SyForm is developed for L<SyContent|https://sycontent.de/>.
 
+B<SyForm> has many B<SyForm::Field>.
+
+With B<SyForm::Process> (automatically added) you can give it B<process_args>
+via calling of B<process(%args)> on your form object that you get from the
+B<create>.
+
+This call to process creates internally a B<SyForm::Values> out of the process
+args together with the help of the fields. Those again use this to produce a
+B<SyForm::Results> with the final results of the process.
+
+Those end up in a B<SyForm::View> together with a B<SyForm::ViewField> for
+every B<SyForm::Field> that is used in the process flow. The view field allows
+easy access to the B<SyForm::Values> values, the B<SyForm::Results> results
+and the actually B<SyForm::Field> definition, to get a complete access of
+all variables in the rendering.
+
+B<WARNING>: B<SyForm::Values> and B<SyForm::Results> produce L<Moose>
+attributes for storing their data, those are named directly after the key
+given for the field on the definition. This is highly risky for collides
+so its best to avoid using any term used in SyForm as key for those fields.
+This will change and getting real attributes will become an optional feature.
+
 =encoding utf8
 
 =head1 SUPPORT
